@@ -37,7 +37,7 @@ const serialhubPlugin: IPlugin<Application<Widget>, void> = {
   requires: [IJupyterWidgetRegistry],
   activate: activateWidgetExtension,
   autoStart: true
-} as unknown as IPlugin<Application<Widget>, void>;
+} // as unknown as IPlugin<Application<Widget>, void>;
 // the "as unknown as ..." typecast above is solely to support JupyterLab 1
 // and 2 in the same codebase and should be removed when we migrate to Lumino.
 
